<?php
/**
 * Page class.
 *
 * @since      2.0.0
 * @package    FAL
 * @subpackage FAL\Page
 * @author     FAL <support@surror.com>
 */

namespace FAL;

defined( 'ABSPATH' ) || exit;

/**
 * Page class.
 */
class Page {

	/**
	 * The single instance of the class.
	 */
	public function __construct() {
		add_action( 'admin_menu', [ $this, 'register_menu' ] );
		add_action( 'admin_enqueue_scripts', [ $this, 'enqueue_scripts' ] );
		add_action( 'plugin_action_links_' . FAL_BASE, [ $this, 'plugin_action_links' ] );
	}

	/**
	 * Add plugin action link.
	 * 
	 * @param  array $links
	 */
	public function plugin_action_links( $links = [] ) {
		$links[] = '<a href="' . admin_url( 'upload.php?page=fal' ) . '">' . __( 'See Library', 'fal' ) . '</a>';
		return $links;
	}

	/**
	 * Register menu in upload.php menu.
	 */
	public function register_menu() {
		add_submenu_page(
			'upload.php',
			__( 'Free Media Library', 'fal' ),
			__( 'Free Media Library', 'fal' ),
			'manage_options',
			'fal',
			[ $this, 'render_page' ]
		);
	}

	/**
	 * Render page.
	 */
	public function render_page() {
		?>
		<div id="fal-root"></div>
		<?php
	}

	/**
	 * Enqueue scripts.
	 * 
	 * @param  string $hook
	 */
	public function enqueue_scripts( $hook = '' ) {

		wp_enqueue_style(
			'fal',
			FAL_URI . 'css/style.css',
			null,
			FAL_VERSION,
			'all'
		);

		wp_enqueue_script(
			'fal',
			FAL_URI . 'build/stats.js',
			[ 
				'lodash',
				'jquery',
				'wp-element',
				'wp-api-fetch',
				'wp-i18n',
				'masonry',
				'imagesloaded',
			],
			FAL_VERSION,
			true
		);

		wp_localize_script( 'fal', 'FAL', [
			'ajax_url' => admin_url( 'admin-ajax.php' ),
		] );
	}

}
